bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma
========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: WrapToGaussianGamma

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianGamma.__init__
      ~WrapToGaussianGamma.add_plate_axis
      ~WrapToGaussianGamma.broadcasting_multiplier
      ~WrapToGaussianGamma.delete
      ~WrapToGaussianGamma.get_mask
      ~WrapToGaussianGamma.get_moments
      ~WrapToGaussianGamma.get_shape
      ~WrapToGaussianGamma.has_plotter
      ~WrapToGaussianGamma.lower_bound_contribution
      ~WrapToGaussianGamma.move_plates
      ~WrapToGaussianGamma.plot
      ~WrapToGaussianGamma.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianGamma.plates
      ~WrapToGaussianGamma.plates_multiplier
   
   